@@ -37,6 +37,15 @@ option_descriptions = {
 
 
 detailed_option_descriptions = {
+    'm': '''You can get all files ordered by mod time with just '-m',
+    or (with version >=0.4.0) you can filter with '-m[><=]=?<date>', where 
+    <date> is any date in YYYY-MM-DD format, or a fragment like yyyy-mm''',
+    
+    's': '''You can get all files ordered by size (desc) with just '-s',
+    or (with gorp version >=0.4.0) you can filter with '-s[><=]=?<size>', 
+    where <size> is a number of bytes, which can be unitless or measured in 
+    bytes, b, KB, MB, or GB''',
+    
     'u': '''The -u option updates text files or renames files and 
     directories, and may use an interactive prompt.
 The general syntax is "subquery (-}} other_subquery)* -}} -u 'function'.
@@ -66,7 +75,7 @@ and then read it in the future with the -e option.''',
     
     'f': f'''This option filters filenames, and ignores filenames with 
 extensions not in the following list:
-{gprint(textTypeFiles, str)}''',
+{gprint(sorted(textTypeFiles), str)}''',
 
     'g': '''The syntax for the -g option is "python -m gorp -g <text file name>".
 Added in version 0.2.4 for command line use only.
