@@ -24,8 +24,8 @@
     file extensions are treated as text files, see site-packages/gorp/utils.py.
 - "gorp doc f" will show a list of "text-type-files".
 '''
-from .utils import *
-from .gprint import gprint
+from gorp.utils import *
+from gorp.gprint import gprint
 
 
 helpstring = __doc__
@@ -297,12 +297,15 @@ def warn_first_import_error(package):
         print(import_warnings[package][1])
 
 
-queryParserRegex = re.compile(("\s*(?P<options>(?:-(?:[a-zA-Z]+|-?\d+)\s+)*)"
+queryParserRegex = re.compile(("\s*(?P<options>(?:-(?:[a-zA-Z]+"
+                               r"(?:[><=]=?[\d\.,-]+(?:[gmk]?b(?:ytes)?)?)?"
+                               # allows filtering of mod times and file sizes
+                               "|-?\d+)\s+)*)" # num option to limit # results
                                r"'(?P<text>(?:[^']|(?<=\\)')*?)(?<!\\)'"
                                # the text regex allows recognition of "'" in the regex
                                # itself, so long as they're preceded by r'\\'
                                "(?:\s+/(?P<fname>[^}\t]+?)"
-                               "(?:\s+-}} |\s*$))?")) 
+                               "(?:\s+-}} |\s*$))?"), re.I) 
 # note that the last part of the regex (the -}} pipe splitter) greedily consumes
 # spaces after the fname. This actually works out fine because neither filenames nor
 # directory names can be terminated by spaces.
@@ -324,22 +327,12 @@ GorpHandlers should only be created by a GorpSession.'''
         GorpLogger.info(f"In GorpHandler.__init__, parsedQuery = {self.parsedQuery}")
         self.readers = []
         self.level = 0
-        self.options = [set(re.findall("(?<=-)\S+", x[0].strip().lower())) for x in self.parsedQuery]
+        self.options = [set(re.findall("-(\S+)", x[0].strip().lower())) for x in self.parsedQuery]
+        # print(f'{self.options = }')
         self.all_options = set(opt for opts in self.options for opt in opts)
         self.regexes = [x[1].replace('\\\'', '\'') for x in self.parsedQuery]
-        if resultset is None:
-            # the resultset has to be generated by reading files in the directory
-            # named by the first subquery.
-            self.firstGorp, self.gorps = self.parsedQuery[0], self.parsedQuery[1:]
-            self.dirName = os.path.abspath(self.firstGorp[2])
-            self.readers.append(FileReader(self.options[0], 
-                                        self.regexes[0], 
-                                        self.dirName,
-                                        self))
-            self.resultset = self.readers[-1].resultset
-        else:
-            self.resultset = resultset
-        
+        self.s = [x for x in self.all_options if x[0] == 's' and x != 'sed']
+        self.m = [x for x in self.all_options if x[0] == 'm' and x != 'mv']
         self.k = 'k' in self.all_options
         self.w = 'w' in self.options[-1]
         self.u = 'u' in self.options[-1]
@@ -367,13 +360,25 @@ GorpHandlers should only be created by a GorpSession.'''
                    f"and replacement_func = compute({self.regexes[-1]})"))
         self.p = 'p' in self.all_options
         self.t = 't' in self.all_options
-        self.s = 's' in self.all_options
-        self.m = 'm' in self.all_options  
         self.f = 'f' in self.options[-1]
         self.l = 'l' in self.options[-1]
         self.c = 'c' in self.options[-1]
         self.h = 'h' in self.options[-1] 
         self.n = 'n' in self.options[-1]
+        # now read the files!
+        if resultset is None:
+            # the resultset has to be generated by reading files in the directory
+            # named by the first subquery.
+            self.firstGorp, self.gorps = self.parsedQuery[0], self.parsedQuery[1:]
+            self.dirName = os.path.abspath(self.firstGorp[2])
+            self.readers.append(FileReader(self.options[0], 
+                                        self.regexes[0], 
+                                        self.dirName,
+                                        self))
+            self.resultset = self.readers[-1].resultset
+        else:
+            self.dirName = os.getcwd()
+            self.resultset = resultset
             
     def refine(self):
         '''Passes the current resultset of the GorpHandler to the next 
@@ -459,21 +464,31 @@ down the resultset'''
             import zipfile
             from gorp.zip_utils import make_relpaths
             write_to_name = increment_name(ext_checker(self.parsedQuery[-1][1], 'zip'))
-            with zipfile.ZipFile(write_to_name, 
+            curdir = os.getcwd()
+            try:
+                zf = zipfile.ZipFile(write_to_name, 
                                  mode = 'w', # 'x' mode is like 'w', but raises error
                                              # if file already exists
                                  compression = self.zip_compression
-                                 ) as zf:
-                if len(self.resultset) > 1:
-                    files = make_relpaths(self.resultset)
+                                 )
+                if not self.resultset:
+                    files = []
+                elif len(self.resultset) > 1:
+                    files, commondir = make_relpaths(self.resultset)
+                    os.chdir(commondir)
                 elif len(self.resultset) == 1:
                     files = [os.path.basename(f) for f in self.resultset]
+                    commondir = [os.path.dirname(f) for f in self.resultset][0]
+                    os.chdir(commondir)
                     # make_relpaths(files) finds the longest path shared by
                     # all paths in files, and truncates all those files to
                     # remove the redundant common part.
                     # But if there's only one file, this chops off everything.
                 for fname in files:
                     zf.write(fname)
+            finally:
+                os.chdir(curdir)
+                zf.close()
         if self.mv: # collect all files, copy them into a directory
             pass
         if not (self.w or self.k or self.p or self.t or self.u):
@@ -707,13 +722,30 @@ class FileReader:
         self.j = ('j' in self.options)
         # self.k = ('k' in self.options) # a post-processing option used on the final resultset
         self.l = ('l' in self.options)
-        self.m = ('m' in self.options)
+        self.m = [x for x in self.options if x[0] == 'm' and x != 'mv']
+        if self.m:
+            m = self.m[0]
+            try:
+                comparator, modtime = re.findall('([<>=]=?)(.+)', m)[0]
+                compare_func = {**binops, '=': binops['==']}[comparator] 
+                self.modtime_filter = lambda x: compare_func(str(x), modtime)
+            except:
+                self.modtime_filter = lambda x: True
         self.n = ('n' in self.options)
         self.o = ('o' in self.options)
         # self.p = ('p' in self.options) # see self.k comment
         # self.q = ('q' in self.options)
         self.r = ('r' in self.options)
-        self.s = ('s' in self.options)
+        self.s = [x for x in self.options if x[0] == 's' and x != 'sed']
+        if self.s:
+            s = self.s[0]
+            try:
+                comparator, size = re.findall('([<>=]=?)(.+)', s)[0]
+                size = byteform_to_num(size)
+                compare_func = {**binops, '=': binops['==']}[comparator]
+                self.size_filter = lambda x: compare_func(x, size)
+            except:
+                self.size_filter = lambda x: True
         # self.t = ('t' in self.options) # see self.k
         self.tab = ('tab' in self.options)
         # self.u = ('u' in self.options) # see self.k
@@ -722,6 +754,7 @@ class FileReader:
         self.x = ('x' in self.options) and not import_warnings['lxml'][0]
         self.y = ('y' in self.options) and not import_warnings['yaml'][0]
         # self.z = ('z' in self.options) # see self.k
+        # print(f'{self.m = }, {self.s = }, {self.r = }')
         
         self.numarg = None
         for opt in self.options:
@@ -819,7 +852,12 @@ class FileReader:
             else:
                 self.resultset = self.resultset[:new_result_len]
         if self.m and self.s: # get size and mod time of each file
-            sizes = [(f, last_mod_time(f, True), os.path.getsize(f)) for f in self.resultset]
+            sizes = list(filter(lambda x: self.modtime_filter(x[1]) \
+                                          and self.size_filter(x[2]),
+                                [(f,
+                                  last_mod_time(f, True), 
+                                  os.path.getsize(f)) \
+                                for f in self.resultset]))
             sizes.sort(key = lambda x: x[2], reverse = True)
             if new_result_len is not None: # truncate after sorting to get largest
                 if new_result_len < 0:
@@ -830,7 +868,9 @@ class FileReader:
             self.resultset = Orddict([(f, (str(mod), format_bytes(siz))) for f,mod,siz in sizes]) 
             # Orddict is just a normal dict for Python 3.7+, else a collections.OrderedDict
         elif self.m: # last mod time; not size
-            modtime_d = [(f,last_mod_time(f,True)) for f in self.resultset]
+            modtime_d = list(filter(lambda x: self.modtime_filter(x[1]),
+                                    [(f, last_mod_time(f,True)) \
+                                    for f in self.resultset]))
             modtime_d.sort(key=lambda x: x[1], reverse=True)
             if new_result_len is not None: # truncate after sorting to get most recent
                 if new_result_len < 0: # get OLDEST files
@@ -840,7 +880,9 @@ class FileReader:
             self.resultset = Orddict((f, str(mod)) for f, mod in modtime_d)
             self.summary = f"{len(self.resultset)} files"
         elif self.s: # get size; not last mod time
-            sizes = [(f, os.path.getsize(f)) for f in self.resultset]
+            sizes = list(filter(lambda x: self.size_filter(x[1]),
+                                [(f, os.path.getsize(f)) \
+                                for f in self.resultset]))
             sizes.sort(key = lambda x: x[1], reverse = True)
             if new_result_len is not None: # truncate after sorting to get largest
                 if new_result_len < 0: # get the new_result_len SMALLEST files
